/*
 *    GSXSLT.java
 *    Copyright (C) 2008 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

import org.w3c.dom.Node;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.w3c.dom.Document;
import org.w3c.dom.Text;

import java.util.HashMap;
import java.util.Vector;
import java.util.ArrayList;

/** various functions for manipulating Greenstone xslt  */
public class GSXSLT {

    /** takes a stylesheet Document, and adds in any child nodes from extra_xsl
     * named templates overwrite any existing one, while match templates are
just added to the end of teh stylesheet
     */
    public static void mergeStylesheets(Document main_xsl, Element extra_xsl) {
	
	Element main = main_xsl.getDocumentElement();
	
	NodeList children = extra_xsl.getElementsByTagNameNS("http://www.w3.org/1999/XSL/Transform", "template");
	for (int i=0; i<children.getLength(); i++) {
	    String name = ((Element)children.item(i)).getAttribute("name");
	    if (!name.equals("")) {
		Element old_template = GSXML.getNamedElement(main, "xsl:template", "name", name);
		if (old_template != null) {
		    main.removeChild(old_template);
		}
	    }
		
	    main.appendChild(main_xsl.importNode(children.item(i), true));
	}

    }

    /** takes any import or include nodes, and creates absolute path names
     * for the files
     */
    public static void absoluteIncludePaths(Document stylesheet, 
					    String gsdl3_home,
					    String site_name,
					    String collection,
					    String interface_name,
					    ArrayList base_interfaces) {
	
	
	Element base_node = stylesheet.getDocumentElement();
	if ( base_node == null ) {
		return;
	}
	Node child = base_node.getFirstChild();
	while(child != null) {
	    String name = child.getNodeName();
	    if (name.equals("xsl:import") || name.equals("xsl:include")) {
		((Element)child).setAttribute("href", GSFile.stylesheetFile(gsdl3_home, site_name, collection, interface_name, base_interfaces, ((Element)child).getAttribute("href")));
	    }
	    child = child.getNextSibling();
	}
	
    }

    /** 
     * looks through a stylesheet for <xxx:template match='template_name'>
     * inside this template it looks for any <xxx:value-of select='metadataList/metadata[@name=yyy]> elements, and extracts the metadata names into a Vector
     */
    public static Vector extractWantedMetadata(Document stylesheet, String template_name) {
	
	Vector metadata = new Vector();
	Element base_node = stylesheet.getDocumentElement();
	NodeList templates = base_node.getElementsByTagNameNS("*","template");
	for (int i=0; i<templates.getLength(); i++) {
	    Element template = (Element)templates.item(i);
	    String match_name = template.getAttribute("match");
	    if (!match_name.equals(template_name)) {
		continue; // we're only looking for specific templates
	    }
	    String mode = template.getAttribute("mode");
	    if (!mode.equals("")) {   
		continue; // we only want ones without modes - these are processing ones, not display ones
	    }
	    // we have one that we want to look through
	    NodeList values = template.getElementsByTagNameNS("*", "value-of");
	    for (int v=0; v<values.getLength(); v++) {
		String select = ((Element)values.item(v)).getAttribute("select");
		if (select.startsWith("metadataList/metadata[@name=")) {
		    String []bits = select.split("'|\"");
		    // there should be two quotes in teh string, therefore 3 items, and the second one is teh one we want
		    String name = bits[1];
		    metadata.add(name);
		}
	    }
	}
	return metadata;	
    }

    

}

